// Squawk messenger. 
// Copyright (C) 2019  Yury Gubich <blue@macaw.me>
// 
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include "omemo.h"
#include "ui_omemo.h"

#include <random>
constexpr uint8_t fingerprintLength = 24;

Omemo::Omemo(QWidget* parent):
    QWidget(parent),
    m_ui(new Ui::Omemo()),
    keysDelegate(),
    unusedKeysDelegate(),
    keysModel(),
    unusedKeysModel()
{
    m_ui->setupUi(this);

    generateMockData();

    m_ui->keysView->setItemDelegate(&keysDelegate);
    m_ui->keysView->setModel(&keysModel);
    m_ui->unusedKeysView->setItemDelegate(&unusedKeysDelegate);
    m_ui->unusedKeysView->setModel(&unusedKeysModel);
}

Omemo::~Omemo()
{

}

void Omemo::generateMockData()
{
    std::random_device rd;
    std::uniform_int_distribution<char> dist(CHAR_MIN, CHAR_MAX);
    for (int i = 0; i < 5; ++i) {
        QByteArray fp(fingerprintLength, 0);
        for (int i = 0; i < fingerprintLength; ++i) {
            fp[i] = dist(rd);
        }
        Shared::KeyInfo info;
        info.id = i;
        info.label = QString("test_") + std::to_string(i).c_str();
        info.fingerPrint = fp;
        keysModel.addKey(info);
    }
}
